@@ -2,7 +2,7 @@
 	
 	/*
 	MGB 0.6.x - OpenSource PHP and MySql Guestbook
-	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/
+	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 
 	// general settings
 	$charset = "utf-8";
-	$language = "Nederlands";
+	$language = "Dutch / Nederlands";
 	$language_short = "nl";
+	$language_version = "1.1.1";
 ?>
