@@ -1,7 +1,7 @@
 <?php
 	/*
 	MGB 0.6 - OpenSource PHP and MySql Guestbook
-	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/
+	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@
 	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 	*/
 
-	// =============================== //
-	// lang_italian.php - Italiano 1.0 //
-	// =============================== //
+	// ============================ //
+	// lang_admin.php - Italian 1.0 //
+	// ============================ //
 	//
 	// This language file was translated by Christian Castelli alias VooDoo (voodoo81people@gmail.com) 
 	//
@@ -73,8 +73,16 @@
 	$lang['no_deactivated_entries'] = "Non ci sono post diattivati.";
 	$lang['no_activated_entries'] = "Non ci sono post attivati";
 	$lang['entries_on_pages'] = "Post in {PAGES} pagine";
+	$lang['page_first'] = "First page";
+	$lang['page_first_symbol'] = "&laquo;";
 	$lang['page_forwards'] = "Sfoglia una pagina in avanti";
+	$lang['page_forwards_symbol'] = "&rsaquo;";
+	$lang['page_last'] = "Last page";
+	$lang['page_last_symbol'] = "&raquo;";
 	$lang['page_backwards'] = "Sfoglia una pagina indietro";
+	$lang['page_backwards_symbol'] = "&lsaquo;";
+	$lang['captcha_method_code'] = "Securitycode";
+	$lang['captcha_method_math'] = "Mathematic";
 	$lang['activate_entry'] = "Attiva questo post";
 	$lang['deactivate_entry'] = "Disattiva questo post";
 	$lang['delete_entry'] = "Cancella questo post";
@@ -141,6 +149,9 @@
 	$lang['edit_bbcode'] = "Codice BB:";
 	$lang['edit_smileys'] = "Smileys:";
 	$lang['edit_captcha'] = "Captcha:";
+	$lang['edit_captcha_method'] = "Sort of captcha:";
+	$lang['edit_akismet_plugin'] = "Akismet-Plugin:";
+	$lang['edit_akismet_api'] = "Akismet API Key:";
 	$lang['edit_user_notification'] = "Notifica utente:";
 	$lang['edit_user_show_email'] = "Usermail presso il guestbook:";
 	$lang['edit_session_timeout'] = "timeout della sesseione:";
@@ -178,6 +189,11 @@
 	$lang['edit_expl_bbcode'] = "Permette all'utente di formattare il testo.";
 	$lang['edit_expl_smileys'] = "Permette all'utente di aggiungere smileys.";
 	$lang['edit_expl_captcha'] = "Se attivato un codice di verifica deve essere immesso per aggiungere un nuovo post o spedire una mail ad un utente.";
+	$lang['edit_expl_captcha_method'] = "You can choose between a securitycode, or a mathematic formula the user has to solve.";
+	$lang['edit_expl_akismet_plugin'] = "Akismet is an external anti-spam-service, that checks new entries on spam. The akismet-plugin can be downloaded at <a href='http://www.m-gb.org/index.php?id=download_gb' title='Download Akismet Plugin'>http://www.m-gb.org/</a>.";
+	$lang['edit_expl_akismet_api'] = "In order to use Akismet you need an <a href='http://akismet.com/signup/#free' title='Akismet API Key'>API Key</a>. Sign in for free and enter it here after registration.";
+	$lang['edit_expl_akismet_check_ok'] = "<span class='same_version'>Akismet is installed!</span>";
+	$lang['edit_expl_akismet_check_fail'] = "<span class='old_version'>Akismet is NOT installed!</span>";
 	$lang['edit_expl_user_notification'] = "Permette all'utente di decidere se sarà avvertito via email se il suo post sarà attivato.";
 	$lang['edit_expl_user_show_email'] = "Permette all'utente di decidere se il suo indirizzo eMail verrà mostrato nel guestbook oppure no. Se disabilita la checkbox nessuno all'infuori dell'amministratore potrà spedirgli una mail.";
 	$lang['edit_expl_session_timeout'] = "Un ut3ente inattivo verrà automaticamente sloggato se questo periodo scade. Espresso in <b>secondi</b>. Il valore dev'essere maggiore o uguale a (>=) <b>60</b>.";
